@@ -14,7 +14,7 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.25.0"
+version = "1.26.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 
@@ -199,7 +199,10 @@ necessary_kconfig_options = {
             "EXT4_FS": True,
             "KINETO_GAN": False,
             "PFT": False,
+            "SAMSUNG_TUI": False,
+            "SEC_RESTRICT_ROOTING": False,
             "SYSVIPC": True,
+            "TZDEV": False,
             "USE_VFB": False,
             "VT": True,
         }
