@@ -3,6 +3,7 @@
 import copy
 import os
 import pmb.config
+import pmb.helpers.git
 
 """ This file constructs the args variable, which is passed to almost all
     functions in the pmbootstrap code base. Here's a listing of the kind of
@@ -62,7 +63,6 @@ import pmb.config
 
        Examples:
        args.deviceinfo (e.g. {"name": "Mydevice", "arch": "armhf", ...})
-       args.pmaports (e.g. {"version": "1", "branch_alpine": "edge", ...})
 """
 
 
@@ -131,7 +131,9 @@ def add_cache(args):
                             "find_aport": {},
                             "pmb.helpers.package.depends_recurse": {},
                             "pmb.helpers.package.get": {},
-                            "pmb.helpers.repo.update": repo_update})
+                            "pmb.helpers.repo.update": repo_update,
+                            "pmb.helpers.git.parse_channels_cfg": {},
+                            "pmb.config.pmaports.read_config": None})
 
 
 def add_deviceinfo(args):
@@ -160,8 +162,10 @@ def init(args):
     check_pmaports_path(args)
     if args.action not in ["init", "config", "bootimg_analyze", "log",
                            "pull", "shutdown", "zap"]:
-        pmb.config.pmaports.read_config_into_args(args)
+        pmb.config.pmaports.read_config(args)
         add_deviceinfo(args)
+        pmb.helpers.git.parse_channels_cfg(args)
+
     return args
 
 
