@@ -178,7 +178,10 @@ def create_home_from_skel(args):
     rootfs = args.work + "/chroot_native/mnt/install"
     homedir = rootfs + "/home/" + args.user
     pmb.helpers.run.root(args, ["mkdir", rootfs + "/home"])
-    pmb.helpers.run.root(args, ["cp", "-a", rootfs + "/etc/skel", homedir])
+    if os.path.exists(f"{rootfs}/etc/skel"):
+        pmb.helpers.run.root(args, ["cp", "-a", f"{rootfs}/etc/skel", homedir])
+    else:
+        pmb.helpers.run.root(args, ["mkdir", homedir])
     pmb.helpers.run.root(args, ["chown", "-R", "10000", homedir])
 
 
@@ -342,13 +345,16 @@ def setup_hostname(args):
     pmb.chroot.root(args, ["sed", "-i", "-e", regex, "/etc/hosts"], suffix)
 
 
-def embed_firmware(args):
+def embed_firmware(args, suffix):
     """
     This method will embed firmware, located at /usr/share, that are specified
     by the "sd_embed_firmware" deviceinfo parameter into the SD card image
     (e.g. u-boot). Binaries that would overwrite the first partition are not
     accepted, and if multiple binaries are specified then they will be checked
     for collisions with each other.
+
+    :param suffix: of the chroot, which holds the firmware files (either the
+                   f"rootfs_{args.device}", or f"installer_{args.device}")
     """
     if not args.deviceinfo["sd_embed_firmware"]:
         return
@@ -362,7 +368,7 @@ def embed_firmware(args):
                                "deviceinfo_sd_embed_firmware_step_size "
                                "is not valid: {}".format(step))
 
-    device_rootfs = mount_device_rootfs(args, f"rootfs_{args.device}")
+    device_rootfs = mount_device_rootfs(args, suffix)
     binaries = args.deviceinfo["sd_embed_firmware"].split(",")
 
     # Perform three checks prior to writing binaries to disk: 1) that binaries
@@ -377,12 +383,12 @@ def embed_firmware(args):
         except ValueError:
             raise RuntimeError("Value for firmware binary offset is "
                                "not valid: {}".format(offset))
-        binary_path = os.path.join(args.work, "chroot_rootfs_" +
-                                   args.device, "usr/share", binary)
+        binary_path = os.path.join(args.work, f"chroot_{suffix}", "usr/share",
+                                   binary)
         if not os.path.exists(binary_path):
             raise RuntimeError("The following firmware binary does not "
-                               "exist in the device rootfs: "
-                               "{}".format("/usr/share/" + binary))
+                               f"exist in the {suffix} chroot: "
+                               f"/usr/share/{binary}")
         # Insure that embedding the firmware will not overrun the
         # first partition
         boot_part_start = args.deviceinfo["boot_part_start"] or "2048"
@@ -495,7 +501,7 @@ def install_system_image(args, size_reserve, suffix, step, steps,
     create_home_from_skel(args)
     configure_apk(args)
     copy_ssh_keys(args)
-    embed_firmware(args)
+    embed_firmware(args, suffix)
     pmb.chroot.shutdown(args, True)
 
     # Convert rootfs to sparse using img2simg
