@@ -22,6 +22,102 @@ import pmb.helpers.pmaports
     See pmb/helpers/args.py for more information about the args variable. """
 
 
+def arguments_install(subparser):
+    ret = subparser.add_parser("install", help="set up device specific"
+                               " chroot and install to SD card or image file")
+
+    # Image type
+    group_desc = ret.add_argument_group(
+        "optional image type",
+        "Format of the resulting image. Default is generating a combined image"
+        " of the postmarketOS boot and root partitions (--no-split). (If the"
+        " device's deviceinfo_flash_method requires separate boot and root"
+        " partitions, then --split is the default.) Related:"
+        " https://postmarketos.org/partitions")
+    group = group_desc.add_mutually_exclusive_group()
+    group.add_argument("--no-split", help="create combined boot and root image"
+                       " file", dest="split", action="store_false",
+                       default=None)
+    group.add_argument("--split", help="create separate boot and root image"
+                       " files", action="store_true")
+    group.add_argument("--sdcard", help="do not create an image file, instead"
+                       " write to the given SD card device (e.g."
+                       " '/dev/mmcblk0')", metavar="BLOCKDEV")
+    group.add_argument("--android-recovery-zip",
+                       help="generate TWRP flashable zip (recommended read:"
+                            " https://postmarketos.org/recoveryzip)",
+                       action="store_true", dest="android_recovery_zip")
+    group.add_argument("--no-image", help="do not generate an image",
+                       action="store_true", dest="no_image")
+
+    # Image type "--sdcard" related
+    group = ret.add_argument_group("optional image type 'sdcard' arguments")
+    group.add_argument("--rsync", help="update the SD card using rsync",
+                       action="store_true")
+
+    # Image type "--android-recovery-zip" related
+    group = ret.add_argument_group("optional image type 'android-recovery-zip'"
+                                   " arguments")
+    group.add_argument("--flavor", help="kernel flavor to include in recovery"
+                       " flashable zip", default=None)
+    group.add_argument("--recovery-install-partition", default="system",
+                       help="partition to flash from recovery (e.g."
+                            " 'external_sd')",
+                       dest="recovery_install_partition")
+    group.add_argument("--recovery-no-kernel",
+                       help="do not overwrite the existing kernel",
+                       action="store_false", dest="recovery_flash_kernel")
+
+    # Full disk encryption (disabled by default, --no-fde has no effect)
+    group = ret.add_argument_group("optional full disk encryption arguments")
+    group.add_argument("--fde", help="use full disk encryption",
+                       action="store_true", dest="full_disk_encryption")
+    group.add_argument("--no-fde", help=argparse.SUPPRESS,
+                       action="store_true", dest="no_fde")
+    group.add_argument("--cipher", help="cryptsetup cipher used to encrypt the"
+                       " the rootfs (e.g. 'aes-xts-plain64')")
+    group.add_argument("--iter-time", help="cryptsetup iteration time (in"
+                       " milliseconds) to use when encrypting the system"
+                       " partition")
+
+    # Packages
+    group = ret.add_argument_group(
+        "optional packages arguments",
+        "Select or deselect packages to be included in the installation.")
+    group.add_argument("--add", help="comma separated list of packages to be"
+                       " added to the rootfs (e.g. 'vim,gcc')",
+                       metavar="PACKAGES")
+    group.add_argument("--no-base",
+                       help="do not install postmarketos-base (advanced)",
+                       action="store_false", dest="install_base")
+    group.add_argument("--no-recommends", dest="install_recommends",
+                       help="do not install packages listed in _pmb_recommends"
+                            " of the UI pmaports",
+                       action="store_false")
+
+    # Sparse image
+    group_desc = ret.add_argument_group(
+        "optional sparse image arguments",
+        "Override deviceinfo_flash_sparse for testing purpose.")
+    group = group_desc.add_mutually_exclusive_group()
+    group.add_argument("--sparse", help="generate sparse image file",
+                       default=None, action="store_true")
+    group.add_argument("--no-sparse", help="do not generate sparse image file",
+                       dest="sparse", action="store_false")
+
+    # On-device installer
+    group = ret.add_argument_group(
+        "optional on-device installer arguments",
+        "Wrap the resulting image in a postmarketOS based installation OS, so"
+        " it can be encrypted and customized on first boot."
+        " Related: https://postmarketos.org/on-device-installer")
+    group.add_argument("--on-device-installer", "--ondev", action="store_true",
+                       help="enable on-device installer")
+    group.add_argument("--no-local-pkgs", dest="install_local_pkgs",
+                       help="do not install locally compiled packages and"
+                            " package signing keys", action="store_false")
+
+
 def arguments_export(subparser):
     ret = subparser.add_parser("export", help="create convenience symlinks"
                                " to generated image files (system, kernel,"
@@ -54,7 +150,8 @@ def arguments_flasher(subparser):
     for action in [boot, flash_kernel]:
         action.add_argument("--flavor", default=None)
         action.add_argument("--no-install", dest="autoinstall", default=True,
-                            help="skip updating kernel/initfs", action="store_false")
+                            help="skip updating kernel/initfs",
+                            action="store_false")
     flash_kernel.add_argument("--partition", default=None,
                               help="partition to flash the kernel to (defaults"
                                    " to deviceinfo_flash_*_partition_kernel)")
@@ -72,9 +169,10 @@ def arguments_flasher(subparser):
 
     # Flash vbmeta
     flash_vbmeta = sub.add_parser("flash_vbmeta",
-                                  help="generate and flash AVB 2.0 image with disable"
-                                       " verification flag set to a partition on the"
-                                       " device (typically called vbmeta)")
+                                  help="generate and flash AVB 2.0 image with"
+                                  " disable verification flag set to a"
+                                  " partition on the device (typically called"
+                                  " vbmeta)")
     flash_vbmeta.add_argument("--partition", default=None,
                               help="partition to flash the vbmeta to (defaults"
                                    " to deviceinfo_flash_*_partition_vbmeta")
@@ -102,8 +200,9 @@ def arguments_initfs(subparser):
     hook_add = sub.add_parser("hook_add", help="add a hook package")
     hook_del = sub.add_parser("hook_del", help="uninstall a hook package")
     for action in [hook_add, hook_del]:
-        action.add_argument("hook", help="name of the hook aport, without the"
-                            " '" + pmb.config.initfs_hook_prefix + "' prefix, for example: 'debug-shell'")
+        action.add_argument("hook", help="name of the hook aport, without"
+                            f" the '{pmb.config.initfs_hook_prefix}' prefix,"
+                            " for example: 'debug-shell'")
 
     # ls, build, extract
     ls = sub.add_parser("ls", help="list initramfs contents")
@@ -115,8 +214,8 @@ def arguments_initfs(subparser):
         action.add_argument(
             "--flavor",
             default=None,
-            help="name of the kernel flavor (run 'pmbootstrap flasher list_flavors'"
-            " to get a list of all installed flavors")
+            help="name of the kernel flavor (run 'pmbootstrap flasher"
+            " list_flavors' to get a list of all installed flavors")
 
     return ret
 
@@ -131,34 +230,38 @@ def arguments_qemu(subparser):
     ret.add_argument("-p", "--port", type=int, default=2222,
                      help="SSH port (default: 2222)")
 
-    ret.add_argument("--no-kvm", dest="qemu_kvm", default=True, action='store_false',
-                     help="Avoid using hardware-assisted virtualization with KVM "
-                     "even when available (SLOW!)")
+    ret.add_argument("--no-kvm", dest="qemu_kvm", default=True,
+                     action='store_false', help="Avoid using hardware-assisted"
+                     " virtualization with KVM even when available (SLOW!)")
     ret.add_argument("--cpu", dest="qemu_cpu",
-                     help="Override emulated QEMU CPU. By default, the host CPU "
-                     "will be emulated when using KVM and the QEMU default otherwise "
-                     "(usually a CPU with minimal features). "
-                     "A useful value is 'max' (emulate all features that are available), "
-                     "use --cpu help to get a list of possible values from QEMU.")
+                     help="Override emulated QEMU CPU. By default, the host"
+                     " CPU will be emulated when using KVM and the QEMU"
+                     " default otherwise (usually a CPU with minimal"
+                     " features). A useful value is 'max' (emulate all"
+                     " features that are available), use --cpu help to get a"
+                     " list of possible values from QEMU.")
 
     ret.add_argument("--tablet", dest="qemu_tablet", action='store_true',
-                     default=False, help="Use 'tablet' instead of 'mouse' input "
-                     "for QEMU. The tablet input device automatically grabs/releases "
-                     "the mouse when moving in/out of the QEMU window. "
-                     "(Note: For some reason the mouse position is not reported "
-                     "correctly with this in some cases...)")
+                     default=False, help="Use 'tablet' instead of 'mouse'"
+                     " input for QEMU. The tablet input device automatically"
+                     " grabs/releases the mouse when moving in/out of the QEMU"
+                     " window. (Note: For some reason the mouse position is"
+                     " not reported correctly with this in some cases...)")
 
-    ret.add_argument("--display", dest="qemu_display", choices=["sdl", "gtk", "none"],
+    ret.add_argument("--display", dest="qemu_display",
+                     choices=["sdl", "gtk", "none"],
                      help="QEMU's display parameter (default: sdl,gl=on)",
                      default="sdl", nargs="?")
-    ret.add_argument("--no-gl", dest="qemu_gl", default=True, action='store_false',
-                     help="Avoid using GL for accelerating graphics in QEMU "
-                     "(use software rasterizer, slow!)")
+    ret.add_argument("--no-gl", dest="qemu_gl", default=True,
+                     action='store_false', help="Avoid using GL for"
+                     " accelerating graphics in QEMU  (use software"
+                     " rasterizer, slow!)")
     ret.add_argument("--video", dest="qemu_video", default="1024x768@60",
-                     help="Video resolution for QEMU (WidthxHeight@RefreshRate). "
-                     "Default is 1024x768@60.")
+                     help="Video resolution for QEMU"
+                     " (WidthxHeight@RefreshRate). Default is 1024x768@60.")
 
-    ret.add_argument("--audio", dest="qemu_audio", choices=["alsa", "pa", "sdl"],
+    ret.add_argument("--audio", dest="qemu_audio",
+                     choices=["alsa", "pa", "sdl"],
                      help="QEMU's audio backend (default: none)",
                      default=None, nargs="?")
 
@@ -187,15 +290,18 @@ def arguments_pkgrel_bump(subparser):
 
 def arguments_aportupgrade(subparser):
     ret = subparser.add_parser("aportupgrade")
-    ret.add_argument("--dry", action="store_true", help="instead of modifying APKBUILDs,"
-                     " print the changes that would be made")
+    ret.add_argument("--dry", action="store_true", help="instead of modifying"
+                     " APKBUILDs, print the changes that would be made")
     ret.add_argument("--ref", help="git ref (tag, commit, etc) to use")
 
     # Mutually exclusive: "--all" or package names
     mode = ret.add_mutually_exclusive_group(required=True)
-    mode.add_argument("--all", action="store_true", help="iterate through all packages")
-    mode.add_argument("--all-stable", action="store_true", help="iterate through all non-git packages")
-    mode.add_argument("--all-git", action="store_true", help="iterate through all git packages")
+    mode.add_argument("--all", action="store_true", help="iterate through all"
+                      " packages")
+    mode.add_argument("--all-stable", action="store_true", help="iterate"
+                      " through all non-git packages")
+    mode.add_argument("--all-git", action="store_true", help="iterate through"
+                      " all git packages")
     mode.add_argument("packages", nargs="*", default=[])
     return ret
 
@@ -274,7 +380,7 @@ def arguments_kconfig(subparser):
     edit.add_argument("-g", dest="gconfig", action="store_true",
                       help="use gconfig rather than ncurses for kernel"
                            " configuration")
-    edit_package = edit.add_argument("package")
+    edit_package = edit.add_argument("package", nargs='?')
     if argcomplete:
         edit_package.completer = kernel_completer
 
@@ -320,7 +426,8 @@ def package_completer(prefix, action, parser, parsed_args):
 
 
 def kernel_completer(prefix, action, parser, parsed_args):
-    packages = package_completer("linux-" + prefix, action, parser, parsed_args)
+    packages = package_completer("linux-" + prefix, action, parser,
+                                 parsed_args)
     return [package.replace("linux-", "", 1) for package in packages]
 
 
@@ -411,8 +518,8 @@ def arguments():
     parser.add_argument("-v", "--verbose", dest="verbose",
                         action="store_true", help="write even more to the"
                         " logfiles (this may reduce performance)")
-    parser.add_argument("-q", "--quiet", dest="quiet",
-                        action="store_true", help="do not output any log messages")
+    parser.add_argument("-q", "--quiet", dest="quiet", action="store_true",
+                        help="do not output any log messages")
 
     # Actions
     sub = parser.add_subparsers(title="action", dest="action")
@@ -451,10 +558,10 @@ def arguments():
     zap.add_argument("--dry", action="store_true", help="instead of actually"
                      " deleting anything, print out what would have been"
                      " deleted")
-    zap.add_argument("-hc", "--http", action="store_true", help="also delete http"
-                     " cache")
-    zap.add_argument("-d", "--distfiles", action="store_true", help="also delete"
-                     " downloaded source tarballs")
+    zap.add_argument("-hc", "--http", action="store_true", help="also delete"
+                     " http cache")
+    zap.add_argument("-d", "--distfiles", action="store_true", help="also"
+                     " delete downloaded source tarballs")
     zap.add_argument("-p", "--pkgs-local", action="store_true",
                      dest="pkgs_local",
                      help="also delete *all* locally compiled packages")
@@ -484,7 +591,8 @@ def arguments():
 
     # Action: build_init / chroot
     build_init = sub.add_parser("build_init", help="initialize build"
-                                " environment (usually you do not need to call this)")
+                                " environment (usually you do not need to call"
+                                " this)")
     chroot = sub.add_parser("chroot", help="start shell in chroot")
     chroot.add_argument("--add", help="build/install comma separated list of"
                         " packages in the chroot before entering it")
@@ -497,7 +605,8 @@ def arguments():
                         " 'background'. Details: pmb/helpers/run_core.py",
                         default="tui")
     chroot.add_argument("command", default=["sh", "-i"], help="command"
-                        " to execute inside the chroot. default: sh", nargs='*')
+                        " to execute inside the chroot. default: sh",
+                        nargs='*')
     chroot.add_argument("-x", "--xauth", action="store_true",
                         help="Copy .Xauthority and set environment variables,"
                              " so X11 applications can be started (native"
@@ -513,74 +622,14 @@ def arguments():
                                 help="Chroot for the device root file system")
         suffix.add_argument("-b", "--buildroot", nargs="?", const="device",
                             choices={"device"} | arch_choices,
-                            help="Chroot for building packages, defaults to device "
-                                 "architecture")
+                            help="Chroot for building packages, defaults to"
+                            " device architecture")
         suffix.add_argument("-s", "--suffix", default=None,
                             help="Specify any chroot suffix, defaults to"
                                  " 'native'")
 
     # Action: install
-    install = sub.add_parser("install", help="set up device specific" +
-                             " chroot and install to sdcard or image file")
-    group = install.add_mutually_exclusive_group()
-    group.add_argument("--sdcard", help="path to the sdcard device,"
-                       " eg. /dev/mmcblk0")
-    group.add_argument("--split", help="install the boot and root partition"
-                       " in separated image files (default: only if flash method"
-                       " requires it)", action="store_true", default=None)
-    group.add_argument("--no-split", help="create combined boot + root image"
-                       " even if flash method requires it",
-                       dest="split", action="store_false")
-    group.add_argument("--android-recovery-zip",
-                       help="generate TWRP flashable zip",
-                       action="store_true", dest="android_recovery_zip")
-    group.add_argument("--no-image", help="do not generate the image",
-                       action="store_true", dest="no_image")
-    install.add_argument("--rsync", help="update the sdcard using rsync,"
-                         " does not work with --fde", action="store_true")
-    install.add_argument("--cipher", help="cryptsetup cipher used to"
-                         " encrypt the rootfs, eg. aes-xts-plain64")
-    install.add_argument("--iter-time", help="cryptsetup iteration time (in"
-                         " milliseconds) to use when encrypting the system"
-                         " partition")
-    install.add_argument("--add", help="comma separated list of packages to be"
-                         " added to the rootfs (e.g. 'vim,gcc')")
-    install.add_argument("--no-fde", help=argparse.SUPPRESS,
-                         action="store_true", dest="no_fde")
-    install.add_argument("--fde", help="use full disk encryption",
-                         action="store_true", dest="full_disk_encryption")
-    install.add_argument("--flavor",
-                         help="Specify kernel flavor to include in recovery"
-                              " flashable zip", default=None)
-    install.add_argument("--recovery-install-partition", default="system",
-                         help="partition to flash from recovery,"
-                              " eg. external_sd",
-                         dest="recovery_install_partition")
-    install.add_argument("--recovery-no-kernel",
-                         help="do not overwrite the existing kernel",
-                         action="store_false", dest="recovery_flash_kernel")
-    install.add_argument("--no-base",
-                         help="do not install postmarketos-base (advanced)",
-                         action="store_false", dest="install_base")
-    install.add_argument("--on-device-installer", "--ondev",
-                         action="store_true",
-                         help="wrap the resulting image in a graphical"
-                              " on-device installer, so the installation can"
-                              " be customized after flashing")
-    install.add_argument("--no-local-pkgs", dest="install_local_pkgs",
-                         help="do not install locally compiled packages and"
-                              " package signing keys", action="store_false")
-    install.add_argument("--no-recommends", dest="install_recommends",
-                         help="do not install packages listed in"
-                              " _pmb_recommends of the UI pmaports",
-                         action="store_false")
-    group = install.add_mutually_exclusive_group()
-    group.add_argument("--sparse", help="generate sparse image file"
-                       " (even if unsupported by device)", default=None,
-                       action="store_true")
-    group.add_argument("--no-sparse", help="do not generate sparse image file"
-                       " (even if supported by device)", dest="sparse",
-                       action="store_false")
+    arguments_install(sub)
 
     # Action: checksum
     checksum = sub.add_parser("checksum", help="update aport checksums")
@@ -591,9 +640,11 @@ def arguments():
 
     # Action: aportgen
     aportgen = sub.add_parser("aportgen", help="generate a postmarketOS"
-                              " specific package build recipe (aport/APKBUILD)")
-    aportgen.add_argument("--fork-alpine", help="fork the alpine upstream package",
-                          action="store_true", dest="fork_alpine")
+                              " specific package build recipe"
+                              " (aport/APKBUILD)")
+    aportgen.add_argument("--fork-alpine", help="fork the alpine upstream"
+                          " package", action="store_true",
+                          dest="fork_alpine")
     add_packages_arg(aportgen, nargs="+")
 
     # Action: build
@@ -605,8 +656,9 @@ def arguments():
                        " APKBUILD)")
     build.add_argument("--force", action="store_true", help="even build if not"
                        " necessary")
-    build.add_argument("--strict", action="store_true", help="(slower) zap and install only"
-                       " required depends when building, to detect dependency errors")
+    build.add_argument("--strict", action="store_true", help="(slower) zap and"
+                       " install only required depends when building, to"
+                       " detect dependency errors")
     build.add_argument("--src", help="override source used to build the"
                        " package with a local folder (the APKBUILD must"
                        " expect the source to be in $builddir, so you might"
@@ -616,8 +668,9 @@ def arguments():
                        help="only build and install makedepends from an"
                        " APKBUILD, ignore the depends (old behavior). This is"
                        " faster for device packages for example, because then"
-                       " you don't need to build and install the kernel. But it"
-                       " is incompatible with how Alpine's abuild handles it.",
+                       " you don't need to build and install the kernel. But"
+                       " it is incompatible with how Alpine's abuild handles"
+                       " it.",
                        dest="ignore_depends")
     build.add_argument("-n", "--no-depends", action="store_true",
                        help="never build dependencies, abort instead",
@@ -649,7 +702,8 @@ def arguments():
     config = sub.add_parser("config",
                             help="get and set pmbootstrap options")
     config.add_argument("-r", "--reset", action="store_true",
-                        help="Reset config options with the given name to it's default.")
+                        help="Reset config options with the given name to it's"
+                        " default.")
     config.add_argument("name", nargs="?", help="variable name, one of: " +
                         ", ".join(sorted(pmb.config.config_keys)),
                         choices=pmb.config.config_keys, metavar="name")
