@@ -6,6 +6,7 @@ import sys
 import shutil
 
 import pmb_test  # noqa
+import pmb_test.const
 import pmb.aportgen
 import pmb.config
 import pmb.helpers.logging
@@ -14,7 +15,9 @@ import pmb.parse
 
 @pytest.fixture
 def args(tmpdir, request):
-    sys.argv = ["pmbootstrap.py", "build", "-i", "device-testsuite-testdevice"]
+    cfg = f"{pmb_test.const.testdata}/channels.cfg"
+    sys.argv = ["pmbootstrap.py", "--config-channels", cfg, "build", "-i",
+                "device-testsuite-testdevice"]
     args = pmb.parse.arguments()
     args.log = args.work + "/log_testsuite.txt"
     pmb.helpers.logging.init(args)
@@ -35,6 +38,9 @@ def args(tmpdir, request):
     pmb.helpers.run.user(args, ["mkdir", "-p", tmpdir + "/device/testing"])
     path_mako = args._aports_real + "/device/testing/linux-lg-mako"
     pmb.helpers.run.user(args, ["cp", "-r", path_mako, tmpdir + "/device/testing"])
+
+    # Copy pmaports.cfg
+    shutil.copy(f"{pmb_test.const.testdata}/pmaports.cfg", args.aports)
     return args
 
 
@@ -48,7 +54,7 @@ def generate(args, monkeypatch, answers):
     """
     # Patched function
     def fake_ask(args, question="Continue?", choices=["y", "n"], default="n",
-                 lowercase_answer=True, validation_regex=None):
+                 lowercase_answer=True, validation_regex=None, complete=None):
         for substr, answer in answers.items():
             if substr in question:
                 logging.info(question + ": " + answer)
@@ -111,6 +117,7 @@ def test_aportgen_device_wizard(args, monkeypatch):
         "Manufacturer": "Testsuite",
         "Name": "Testsuite Testdevice",
         "Year": "1337",
+        "Chassis": "handset",
         "Type": "isorec",
     }
 
@@ -120,7 +127,7 @@ def test_aportgen_device_wizard(args, monkeypatch):
     assert apkbuild["pkgdesc"] == "Testsuite Testdevice"
     assert apkbuild["depends"] == ["postmarketos-base",
                                    "linux-testsuite-testdevice",
-                                   "mesa-dri-swrast"]
+                                   "mesa-dri-gallium"]
 
     assert apkbuild_linux["pkgname"] == "linux-testsuite-testdevice"
     assert apkbuild_linux["pkgdesc"] == "Testsuite Testdevice kernel fork"
@@ -131,6 +138,7 @@ def test_aportgen_device_wizard(args, monkeypatch):
     assert deviceinfo["manufacturer"] == answers["Manufacturer"]
     assert deviceinfo["arch"] == "armhf"
     assert deviceinfo["year"] == "1337"
+    assert deviceinfo["chassis"] == "handset"
     assert deviceinfo["keyboard"] == "false"
     assert deviceinfo["external_storage"] == "true"
     assert deviceinfo["flash_method"] == "heimdall-isorec"
@@ -156,7 +164,7 @@ def test_aportgen_device_wizard(args, monkeypatch):
     deviceinfo, apkbuild, apkbuild_linux = generate(args, monkeypatch, answers)
     assert apkbuild["depends"] == ["postmarketos-base",
                                    "linux-testsuite-testdevice", "mkbootimg",
-                                   "mesa-dri-swrast"]
+                                   "mesa-dri-gallium"]
     assert deviceinfo["flash_method"] == answers["Flash method"]
     assert deviceinfo["generate_bootimg"] == "true"
 
@@ -165,5 +173,5 @@ def test_aportgen_device_wizard(args, monkeypatch):
     deviceinfo, apkbuild, apkbuild_linux = generate(args, monkeypatch, answers)
     assert apkbuild["depends"] == ["postmarketos-base",
                                    "linux-testsuite-testdevice", "uboot-tools",
-                                   "mesa-dri-swrast"]
+                                   "mesa-dri-gallium"]
     assert deviceinfo["generate_legacy_uboot_initfs"] == "true"
