@@ -182,10 +182,10 @@ def test_build_depends_binary_outdated(args, monkeypatch):
     def func_patch(args, package, *args2, **kwargs):
         print(f"func_patch: called for package: {package}")
         if package == "hello-world":
-            print(f"pretending that it does not exist")
+            print("pretending that it does not exist")
             return None
         if package == "binutils-aarch64":
-            print(f"pretending that it is outdated")
+            print("pretending that it is outdated")
             ret = func_orig(args, package, *args2, **kwargs)
             ret["version"] = "0-r0"
             return ret
@@ -351,8 +351,9 @@ def test_build_depends_high_level(args, monkeypatch):
                         fake_build_is_necessary)
 
     # Build hello-world to get its full output path
+    channel = pmb.config.pmaports.read_config(args)["channel"]
     output_hello = pmb.build.package(args, "hello-world")
-    output_hello_outside = args.work + "/packages/" + output_hello
+    output_hello_outside = f"{args.work}/packages/{channel}/{output_hello}"
     assert os.path.exists(output_hello_outside)
 
     # Make sure the wrapper exists
@@ -385,8 +386,8 @@ def test_build_local_source_high_level(args, tmpdir):
     aports = tmpdir + "/aports"
     aport = aports + "/device/testing/device-" + args.device
     os.makedirs(aport)
-    shutil.copy(args.aports + "/device/testing/device-" + args.device + "/deviceinfo",
-                aport)
+    path_original = pmb.helpers.pmaports.find(args, f"device-{args.device}")
+    shutil.copy(f"{path_original}/deviceinfo", aport)
 
     # aports: Add modified hello-world aport (source="", uses $builddir)
     aport = aports + "/main/hello-world"
@@ -411,9 +412,10 @@ def test_build_local_source_high_level(args, tmpdir):
     pmb.helpers.run.root(args, ["chmod", "500", unreadable])
 
     # Test native arch and foreign arch chroot
+    channel = pmb.config.pmaports.read_config(args)["channel"]
     for arch in [args.arch_native, "armhf"]:
         # Delete all hello-world --src packages
-        pattern = args.work + "/packages/" + arch + "/hello-world-*_p*.apk"
+        pattern = f"{args.work}/packages/{channel}/{arch}/hello-world-*_p*.apk"
         for path in glob.glob(pattern):
             pmb.helpers.run.root(args, ["rm", path])
         assert len(glob.glob(pattern)) == 0
